@@ -7,10 +7,16 @@ use Furl;
 use Diff::LibXDiff;
 
 use Class::Accessor::Lite (
-    ro  => [qw/ req ua diff /],
+    ro  => [qw/
+        req
+        ua
+        diff
+        hook_before
+        hook_after
+    /],
 );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my ($class, $left, $right, $options) = @_;
@@ -19,6 +25,8 @@ sub new {
         req => [ _init_req($left), _init_req($right) ],
         ua  => $options->{ua} || Furl->new,
         diff => $options->{diff},
+        hook_before => $options->{hook_before},
+        hook_after  => $options->{hook_after},
     }, $class;
 }
 
@@ -35,18 +43,40 @@ sub _init_req {
 sub report {
     my $self = shift;
 
+    my $responses = $self->_request;
+    my $diff = $self->_diff($responses);
+
+    return $diff;
+}
+
+sub _request {
+    my $self = shift;
+
     my @responses;
+
     for my $req ( @{ $self->req } ) {
+        if ($self->hook_before) {
+            $self->hook_before->($self, $req);
+        }
         my $res = $self->ua->request($req);
-        push @responses, $res->content;
+        my $content = $self->hook_after
+                    ? $self->hook_after->($self, $res, $req) : $res->content;
+        push @responses, $content;
     }
 
+    return \@responses;
+}
+
+sub _diff {
+    my ($self, $responses) = @_;
+
     my $diff;
+
     if ($self->diff) {
-        $diff = $self->diff->(@responses);
+        $diff = $self->diff->(@{$responses});
     }
     else {
-        $diff = Diff::LibXDiff->diff(@responses);
+        $diff = Diff::LibXDiff->diff(@{$responses});
     }
 
     return $diff;
@@ -120,6 +150,28 @@ If you want to use an other diff tool, you'll set C<diff> param as code ref.
         },
     );
 
+=item B<hook_before>
+
+=item B<hook_after>
+
+There are hooks around the request.
+
+    use Web::Compare;
+    
+    my $wc = Web::Compare->new(
+        $lefturl, $righturl, {
+            hook_before => sub {
+                my ($self, $req) = @_;
+                $req->header('X-foo' => 'baz');
+            },
+            hook_after => sub {
+                my ($self, $res, $req) = @_;
+                (my $content = $res->content) =~ s!Hello!Hi!;
+                return $content;
+            },
+        },
+    );
+
 =back
 
 =head2 report
